<?php

namespace Drupal\site_settings\Form;

use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\site_settings\Entity\SiteSettingEntityType;

/**
 * Form controller for Site Setting edit forms.
 *
 * @ingroup site_settings
 */
class SiteSettingEntityForm extends ContentEntityForm {

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    /* @var $entity \Drupal\site_settings\Entity\SiteSettingEntity */
    $form = parent::buildForm($form, $form_state);
    $entity = $this->entity;
    $entity_bundle = $entity->bundle();
    $entity_type = $entity->getEntityTypeId();
    $bundles = $this->entityManager->getBundleInfo($entity_type);
    $bundle = SiteSettingEntityType::load($entity_bundle);

    $form['heading1'] = [
      '#markup' => '<h2>' . $bundles[$entity_bundle]['label'] . '</h2>',
    ];

    // Set entity title and fieldset to match the bundle.
    $form['name']['widget'][0]['value']['#value'] = $bundles[$entity_bundle]['label'];
    $form['fieldset']['widget'][0]['value']['#value'] = $bundle->fieldset;

    // Hide fields.
    hide($form['name']);
    hide($form['user_id']);
    hide($form['fieldset']);
    hide($form['multiple']);

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);

    $entity = $this->entity;
    $entity_bundle = $entity->bundle();
    $entity_type = $entity->getEntityType()->getBundleEntityType();

    // Get existing entities in this settings bundle.
    $query = \Drupal::entityManager()->getStorage('site_setting_entity')->getQuery();
    $query->condition('type', $entity_bundle);
    $existing = $query->execute();
    $bundle = \Drupal::entityManager()->getStorage($entity_type)->load($entity_bundle);

    if (!$bundle->multiple) {
      if (count($existing) > 0 && $entity->id() != reset($existing)) {
        $form_state->setErrorByName('name', $this->t('There can only be one of this setting.'));
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $entity = $this->entity;
    $entity->fieldset = $values['fieldset'];
    $entity->multiple = $values['multiple'];
    $entity->save();
    $status = parent::save($form, $form_state);

    switch ($status) {
      case SAVED_NEW:
        drupal_set_message($this->t('Created the %label Site Setting.', [
          '%label' => $entity->label(),
        ]));
        break;

      default:
        drupal_set_message($this->t('Saved the %label Site Setting.', [
          '%label' => $entity->label(),
        ]));
    }

    // Rebuild the site settings cache.
    $site_settings = \Drupal::service('site_settings.loader');
    $site_settings->rebuildCache();

    $form_state->setRedirect('entity.site_setting_entity.collection');
  }

}
